@@ -17,6 +17,9 @@ from debug import *
 # characters which must not appear in filenames
 filename_deniedchars = map(chr, range(32))
 
+class SessionExit(Exception):
+    pass
+
 class BasicSession:
 
     def __init__(self, rfile, wfile, client_address):
@@ -128,7 +131,7 @@ class BasicSession:
 
     def cmd_quit(self,_):
         self.reply("221 Have a good one!")
-        raise "session_exit"
+        raise SessionExit
 
     def cmd_abor(self,_):
         if self.pendingconn and threading:
@@ -594,7 +597,7 @@ class BasicSession:
                 break
             try:
                 self.docmd(l)
-            except ("session_exit", socket.error):
+            except (SessionExit, socket.error):
                 break
         try:
             self.close_datasock() # close any transfers
